# pinard

pinard is a python package developed at CIRAD (www.cirad.fr) by Grégory Beurier (beurier@cirad.fr), Denis Cornet (denis.cornet@cirad.fr) and Lauriane Rouan (lauriane.rouan@cirad.fr) to enhance Near Infrared Spectroscopy files processing.

It provides set of tools to load, filter, noise, manage and regress sets of NIRS spectrum files. 

## INSTALLATION
pinard is available with pip:

pip install pinard

## USAGE

see examples folder
